==> bitfront-library-6.6.2.tgz: package/src/app/shared/component/form/bit-dropdown.component.ts <==
import { Component, forwardRef, OnChanges, Input, SimpleChange, ChangeDetectorRef } from "@angular/core";
import { NG_VALUE_ACCESSOR } from "@angular/forms";
import { ActivatedRoute } from "@angular/router";

import { AyudaService } from "../../service/ayuda.service";
import { SessionSharedService } from "../../service/session-shared.service";
import { BitDropDownGeneralComponent } from "./bitdropdown-general.component";

export const CUSTOM_DROPDOWN_CONTROL_VALUE_ACCESSOR: any = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: forwardRef(() => BitDropDownComponent),
  multi: true
};

/**
 * Clase que utiliza un custom componente para select de elementos
 * Utiliza la interfaz ControlValueAccessor
 *    <bit-select [domain]="'DOMAIN_TIPO_LOG'" id="tipolog" [control]="formControl">&nbsp;&nbsp;Tipus d'operació</bit-select>
 *
 * @input data: array de objetos a mostrar en el select. Puede ser null, en cuyo caso domain no puede ser null
 * @input domain: nombre del dominio que contiene los datos y que nos resolverá la página cuando cargue el componente. Puede ser null, en cuyo caso data no puede ser null
 * @input id: identificador del componente select
 * @input filter: true indicará que podemos buscar dentro del select, false que no.
 **/
@Component({
  selector: "bit-dropdown",
  templateUrl: "bit-dropdown.component.html",
  providers: [CUSTOM_DROPDOWN_CONTROL_VALUE_ACCESSOR]
})
export class BitDropDownComponent extends BitDropDownGeneralComponent implements OnChanges {
  @Input() filter: boolean = false;
  @Input() excludedValues: any[];
  @Input() autoWidth: boolean;
  @Input() emptyText: string = "Qualsevol"; //valor por defecto seleccionable como primer elemento
  @Input() includeEmpty: boolean = true;

  listaOpcionesVisible: any[] = [];

  constructor(
    protected router: ActivatedRoute,
    protected sessionShared: SessionSharedService,
    protected ayudaService: AyudaService,
    protected changeDetectorRef: ChangeDetectorRef
  ) {
    super(router, sessionShared, ayudaService, changeDetectorRef);
  }

  ngOnChanges(changes: { [propKey: string]: SimpleChange }) {
    let hayCambios: boolean = false;
    for (let propName in changes) {
      let changedProp = changes[propName];
      if (propName === "data") {
        this.listaOpciones = changedProp.currentValue ? changedProp.currentValue.slice() : [];
        hayCambios = true;
      } else if (propName === "dominio") {
        this.domain = changedProp.currentValue;
        // TODO: recargar dominio por si es distinto?
      } else if (propName === "excludedValues") {
        this.excludedValues = changedProp.currentValue;
        hayCambios = true;
      } else if (propName === "includeEmpty") {
        this.includeEmpty = changedProp.currentValue;
        hayCambios = true;
      }
    }
    if (hayCambios) {
      this.postRetrieveData();
    }
  }

  // custom processing after retrieving data array from service
  postRetrieveData() {
    if (this.listaOpciones) {
      this.listaOpcionesVisible = Object.assign([], this.listaOpciones);
      if (this.includeEmpty) {
        // determinamos si debemos incluir la opción "sin selección" y con qué texto
        this.listaOpcionesVisible.splice(0, 0, { value: null, label: this.emptyText });
      }
      // repasamos si hay opciones a excluir que debamos eliminar
      if (this.excludedValues) {
        this.listaOpcionesVisible = this.listaOpcionesVisible.filter(op => this.excludedValues.indexOf(op.value) < 0);
      }
    }
  }

  get value_lectura(): any {
    let val = this.value;
    let dom = this.listaOpciones && this.listaOpciones.find(d => d.value == val);
    return dom ? dom.label : null;
  }
}

==> bitfront-library-7.2.2.tgz: package/src/app/shared/component/form/bit-dropdown.component.ts <==
import { Component, forwardRef, OnChanges, Input, SimpleChange, ChangeDetectorRef } from "@angular/core";
import { NG_VALUE_ACCESSOR } from "@angular/forms";
import { ActivatedRoute } from "@angular/router";

import { AyudaService } from "../../service/ayuda.service";
import { SessionSharedService } from "../../service/session-shared.service";
import { BitDropDownGeneralComponent } from "./bit-dropdown-general.component";

export const CUSTOM_DROPDOWN_CONTROL_VALUE_ACCESSOR: any = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: forwardRef(() => BitDropDownComponent),
  multi: true
};

/**
 * Clase que utiliza un custom componente para select de elementos
 * Utiliza la interfaz ControlValueAccessor
 *    <bit-select [domain]="'DOMAIN_TIPO_LOG'" id="tipolog" [control]="formControl">&nbsp;&nbsp;Tipus d'operació</bit-select>
 *
 * @input data: array de objetos a mostrar en el select. Puede ser null, en cuyo caso domain no puede ser null
 * @input domain: nombre del dominio que contiene los datos y que nos resolverá la página cuando cargue el componente. Puede ser null, en cuyo caso data no puede ser null
 * @input id: identificador del componente select
 * @input filter: true indicará que podemos buscar dentro del select, false que no.
 **/
@Component({
  selector: "bit-dropdown",
  templateUrl: "bit-dropdown.component.html",
  providers: [CUSTOM_DROPDOWN_CONTROL_VALUE_ACCESSOR]
})
export class BitDropDownComponent extends BitDropDownGeneralComponent implements OnChanges {
  @Input() filter: boolean = false;
  @Input() excludedValues: any[];
  @Input() autoWidth: boolean;
  @Input() emptyText: string = "Qualsevol"; //valor por defecto seleccionable como primer elemento
  @Input() includeEmpty: boolean = true;

  listaOpcionesVisible: any[] = [];

  constructor(
    protected router: ActivatedRoute,
    protected sessionShared: SessionSharedService,
    protected ayudaService: AyudaService,
    protected changeDetectorRef: ChangeDetectorRef
  ) {
    super(router, sessionShared, ayudaService, changeDetectorRef);
  }

  ngOnChanges(changes: { [propKey: string]: SimpleChange }) {
    super.ngOnChanges(changes);
    let hayCambios: boolean = false;
    for (let propName in changes) {
      let changedProp = changes[propName];
      if (propName === "data") {
        this.listaOpciones = changedProp.currentValue ? changedProp.currentValue.slice() : [];
        hayCambios = true;
      } else if (propName === "dominio") {
        this.domain = changedProp.currentValue;
        // TODO: recargar dominio por si es distinto?
      } else if (propName === "excludedValues") {
        this.excludedValues = changedProp.currentValue;
        hayCambios = true;
      } else if (propName === "includeEmpty") {
        this.includeEmpty = changedProp.currentValue;
        hayCambios = true;
      }
    }
    if (hayCambios) {
      this.postRetrieveData();
    }
  }

  // custom processing after retrieving data array from service
  postRetrieveData() {
    if (this.listaOpciones) {
      this.listaOpcionesVisible = Object.assign([], this.listaOpciones);
      if (this.includeEmpty) {
        // determinamos si debemos incluir la opción "sin selección" y con qué texto
        this.listaOpcionesVisible.splice(0, 0, { value: null, label: this.emptyText });
      }
      // repasamos si hay opciones a excluir que debamos eliminar
      if (this.excludedValues) {
        this.listaOpcionesVisible = this.listaOpcionesVisible.filter(op => this.excludedValues.indexOf(op.value) < 0);
      }
    }
  }

  get value_lectura(): any {
    let val = this.value;
    let dom = this.listaOpciones && this.listaOpciones.find(d => d.value == val);
    return dom ? dom.label : null;
  }
}
